package org.example;

import com.mongodb.client.MongoClient;
import com.mongodb.client.MongoClients;
import com.mongodb.client.MongoCollection;
import com.mongodb.client.MongoDatabase;
import org.apache.commons.lang3.RandomStringUtils;
import org.bson.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;
import java.util.UUID;

public class UsersGenerator {
    private static final String MONGO_DB_URL = "mongodb://192.168.80.136:27020/";
    private static final String DB_NAME = "mydb";
    private static final String COLLECTION_NAME = "user";
    private static final Random random = new Random();

    public static void main(String[] args) {
        MongoDatabase myDb = connectToMongoDB(MONGO_DB_URL, DB_NAME);
        generateUsers(10000, myDb, COLLECTION_NAME);
    }

    private static MongoDatabase connectToMongoDB(String url, String dbName) {
        MongoClient mongoClient = MongoClients.create(url);
        return mongoClient.getDatabase(dbName);
    }

    private static void generateUsers(int numberOfUsers, MongoDatabase database, String collectionName) {
        MongoCollection<Document> collection = database.getCollection(collectionName);
        System.out.println("Generating " + numberOfUsers + " users");

        for (int userIndex = 0; userIndex < numberOfUsers; userIndex++) {
            Document document = new Document();
            document.append("_id", UUID.randomUUID().toString())
                    .append("userName",generateUserName() )
                    .append("watched_movies", generateWatchedMovies())
                    .append("subscription_month", generateSubscriptionMonth());

            collection.insertOne(document);
        }

        System.out.println("Finished generating users");
    }

    private static List<String> generateWatchedMovies() {
        int numberOfMovies = random.nextInt(10) + 1;
        List<String> watchedMovies = new ArrayList<>(numberOfMovies);

        for (int i = 0; i < numberOfMovies; i++) {
            watchedMovies.add(generateMovieTitle());
        }

        return watchedMovies;
    }

    private static int generateSubscriptionMonth() {
        return random.nextInt(12) + 1; // Generate random subscription month between 1 and 12
    }

    private static String generateMovieTitle() {
        String[] movieTitles = {"Inside Out", "Aladdin", "The Lion King", "Frozen", "Toy Story", "Finding Nemo"};
        return movieTitles[random.nextInt(movieTitles.length)];
    }
    private static String generateUserName() {

            String firstName = generateName();
            String lastName = generateName();


        return firstName+" "+lastName;
    }
    private static String generateName() {
        StringBuilder name = new StringBuilder();

        name.append(RandomStringUtils.randomAlphabetic(1).toUpperCase());
        name.append(RandomStringUtils.randomAlphabetic(5, 10).toLowerCase());

        return name.toString();
    }

}
